<?php
namespace Phppot;
// This example sets up an endpoint using the Slim framework.
// Watch this video to get started: https://youtu.be/sGcNPFX1Ph4.

use Slim\Http\Request;
use Slim\Http\Response;
use Stripe\Stripe;


require_once __DIR__ . '/../Common/Config.php';

class StripeService
{
    function __construct()
    {
        require_once __DIR__ . "/../vendor/autoload.php";
        // Set your secret key. Remember to switch to your live secret key in production!
        // See your keys here: https://dashboard.stripe.com/account/apikeys
        \Stripe\Stripe::setApiKey(Config::STRIPE_SECRET_KEY);
    }

    public function createCheckoutSession($unitAmount, $clientReferenceId)
    {
        $checkout_session = \Stripe\Checkout\Session::create([
            'payment_method_types' => ['card'],
            'line_items' => [[
                'price_data' => [
                    'currency' => Config::CURRENCY,
                    'unit_amount' => $unitAmount,
                    'product_data' => [
                        'name' => Config::PRODUCT_NAME,
                        'images' => [Config::PRODUCT_IMAGE],
                    ],
                ],
                'quantity' => 1,
            ]],
            'mode' => 'payment',
            'client_reference_id' => $clientReferenceId,
            'success_url' => Config::ROOT_PATH . '/success.php?session_id={CHECKOUT_SESSION_ID}',
            'cancel_url' => Config::ROOT_PATH . '/index.php?status=cancel',
        ]);
        return $checkout_session;
    }

    public function captureResponse()
    {
        $payload = @file_get_contents('php://input');


        $event = json_decode($payload);

        require_once __DIR__ . "/../lib/StripePayment.php";
        $stripePayment = new StripePayment();

        switch($event->type) {
            case "customer.created":
                $param["stripe_customer_id"] = $event->data->object->id;
                $param["email"] = $event->data->object->email;
                $param["customer_created_datetime"] = date("Y,m,d H:i:s", $event->data->object->created);
                $param["stripe_response"] = json_encode($event->data->object);
                $stripePayment->insertCustomer($param);
                break;


            case "checkout.session.completed":
                $param["order_id"] = $event->data->object->client_reference_id;
                $param["customer_id"] = $event->data->object->customer;
                $param["payment_intent_id"] = $event->data->object->payment_intent;
                $param["stripe_checkout_response"] = json_encode($event->data->object);
                $stripePayment->updateOrder($param);
                break;


            case "payment_intent.created":
                $param["payment_intent_id"] = $event->data->object->id;
                $param["payment_create_at"] = date("Y-m-d H:i:s", $event->data->object->created);
                $param["payment_status"] = $event->data->object->status;
                $param["stripe_payment_response"] = json_encode($event->data->object);
                $stripePayment->insertPayment($param);
                break;


            case "payment_intent.succeeded":
                //$myfile = fopen("response.log", "a");
                //fwrite($myfile, $payload);
                $param["payment_intent_id"] = $event->data->object->id;
                $param["billing_name"] = $event->data->object->charges->data[0]->billing_details->name;
                $param["billing_email"] = $event->data->object->charges->data[0]->billing_details->email;
                $param["payment_last_updated"] = date("Y-m-d H:i:s", $event->data->object->charges->data[0]->created);
                $param["payment_status"] = $event->data->object->charges->data[0]->status;
                $param["stripe_payment_response"] = json_encode($event->data->object);
                $stripePayment->updatePayment($param);
                break;

            case "payment_intent.canceled":
                $param["payment_intent_id"] = $event->data->object->id;
                $param["billing_name"] = $event->data->object->charges->data[0]->billing_details->name;
                $param["billing_email"] = $event->data->object->charges->data[0]->billing_details->email;
                $param["payment_last_updated"] = date("Y-m-d H:i:s", $event->data->object->charges->data[0]->created);
                $param["payment_status"] = $event->data->object->charges->data[0]->status;
                $param["stripe_payment_response"] = json_encode($event->data->object);
                $stripePayment->updatePayment($param);
                break;


            case "payment_intent.payment_failed":
                $param["payment_intent_id"] = $event->data->object->id;
                $param["billing_name"] = $event->data->object->charges->data[0]->billing_details->name;
                $param["billing_email"] = $event->data->object->charges->data[0]->billing_details->email;
                $param["payment_last_updated"] = date("Y-m-d H:i:s", $event->data->object->charges->data[0]->created);
                $param["payment_status"] = $event->data->object->charges->data[0]->status;
                $param["stripe_payment_response"] = json_encode($event->data->object);
                $stripePayment->updatePayment($param);
                break;
        }

        http_response_code(200);
    }
}